# ramanujantools

[![CI](https://github.com/RamanujanMachine/ramanujantools/actions/workflows/python-package.yml/badge.svg)](https://github.com/RamanujanMachine/ramanujantools/actions/workflows/python-package.yml)
[![PyPI version](https://img.shields.io/pypi/v/ramanujantools.svg)](https://pypi.org/project/ramanujantools/)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15709905.svg)](https://doi.org/10.5281/zenodo.15709905)

Official symbolic and numeric research tools developed by the Ramanujan Machine research group.

## About

`ramanujantools` is a research focused python library that provides symbolic and numeric tools for exploring Polynomial Continued Fractions (PCFs), Linear Recurrences and Conservative Matrix Fields (CMFs). These can be used to discover new conjectures converging sequences to constants of interest such as *e*, *π*, *G* (Catalan's constant), *γ* (Euler's constant), *δ* (Gompertz constant) and integer values of the Riemann Zeta function *ζ(s)*.

## Installation

```bash
pip install ramanujantools
```

## Contributing
Contributions are welcome! Please open issues or pull requests on GitHub.

## Citation

If you use this package in your research, please cite it using the metadata in [`CITATION.cff`](./CITATION.cff), or refer to the citation instructions on our [GitHub repository](https://github.com/RamanujanMachine/ramanujantools).

## License

This project is licensed under the terms of the [MIT License](./LICENSE).

## Links

- Website: [https://www.ramanujanmachine.com](https://www.ramanujanmachine.com)
- Repository: [https://github.com/RamanujanMachine/ramanujantools](https://github.com/RamanujanMachine/ramanujantools)
- Citation file: [`CITATION.cff`](https://github.com/RamanujanMachine/ramanujantools/blob/master/CITATION.cff)
